<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AccountItem</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="40"/>
        <source>Sync successful</source>
        <translation>Sync successful</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="41"/>
        <source>Network error</source>
        <translation>Network error</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="42"/>
        <source>Server exception</source>
        <translation>Server exception</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="43"/>
        <source>Storage full</source>
        <translation>Storage full</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="227"/>
        <source>Local account</source>
        <translation>Local account</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="229"/>
        <source>Event types</source>
        <translation>Event types</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="77"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="90"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="92"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="33"/>
        <source>Monday</source>
        <translation>Monday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="34"/>
        <source>Tuesday</source>
        <translation>Tuesday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="35"/>
        <source>Wednesday</source>
        <translation>Wednesday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="36"/>
        <source>Thursday</source>
        <translation>Thursday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="37"/>
        <source>Friday</source>
        <translation>Friday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="38"/>
        <source>Saturday</source>
        <translation>Saturday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="39"/>
        <source>Sunday</source>
        <translation>Sunday</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="112"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="113"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="114"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="170"/>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsview.cpp" line="592"/>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsItem/cmonthschedulenumitem.cpp" line="80"/>
        <source>%1 more</source>
        <translation>%1 more</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="50"/>
        <source>New event</source>
        <translation>New event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="210"/>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="98"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="267"/>
        <source>My Event</source>
        <translation>My Event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="308"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="312"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="313"/>
        <source>Edit</source>
        <comment>button</comment>
        <translation>Edit</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cpushbutton.cpp" line="17"/>
        <source>New event type</source>
        <translation>New event type</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="45"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="600"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="896"/>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="58"/>
        <source>Edit Event</source>
        <translation>Edit Event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="256"/>
        <source>End time must be greater than start time</source>
        <translation>End time must be greater than start time</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="257"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="481"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="510"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1108"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1143"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1397"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1401"/>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="482"/>
        <source>At time of event</source>
        <translation>At time of event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="483"/>
        <source>15 minutes before</source>
        <translation>15 minutes before</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="484"/>
        <source>30 minutes before</source>
        <translation>30 minutes before</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="485"/>
        <source>1 hour before</source>
        <translation>1 hour before</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="486"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="512"/>
        <source>1 day before</source>
        <translation>1 day before</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="487"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="513"/>
        <source>2 days before</source>
        <translation>2 days before</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="488"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="514"/>
        <source>1 week before</source>
        <translation>1 week before</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="511"/>
        <source>On start day (9:00 AM)</source>
        <translation>On start day (9:00 AM)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="558"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="766"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1164"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1165"/>
        <source>time(s)</source>
        <translation>time(s)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="573"/>
        <source>Enter a name please</source>
        <translation>Enter a name please</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="668"/>
        <source>The name can not only contain whitespaces</source>
        <translation>The name can not only contain whitespaces</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="724"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="846"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="729"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="881"/>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="734"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="918"/>
        <source>All Day:</source>
        <translation>All Day:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="739"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="984"/>
        <source>Starts:</source>
        <translation>Starts:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="744"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1025"/>
        <source>Ends:</source>
        <translation>Ends:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="749"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1065"/>
        <source>Remind Me:</source>
        <translation>Remind Me:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="754"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1097"/>
        <source>Repeat:</source>
        <translation>Repeat:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="759"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1131"/>
        <source>End Repeat:</source>
        <translation>End Repeat:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="815"/>
        <source>Calendar account:</source>
        <translation>Calendar account:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="816"/>
        <source>Calendar account</source>
        <translation>Calendar account</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="843"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="885"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="915"/>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="939"/>
        <source>Time:</source>
        <translation>Time:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="940"/>
        <source>Time</source>
        <translation>Time</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="947"/>
        <source>Solar</source>
        <translation>Solar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="948"/>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="981"/>
        <source>Starts</source>
        <translation>Starts</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1022"/>
        <source>Ends</source>
        <translation>Ends</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1067"/>
        <source>Remind Me</source>
        <translation>Remind Me</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1094"/>
        <source>Repeat</source>
        <translation>Repeat</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1109"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1402"/>
        <source>Daily</source>
        <translation>Daily</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1110"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1403"/>
        <source>Weekdays</source>
        <translation>Weekdays</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1111"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1404"/>
        <source>Weekly</source>
        <translation>Weekly</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1112"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1398"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1405"/>
        <source>Monthly</source>
        <translation>Monthly</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1113"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1399"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1406"/>
        <source>Yearly</source>
        <translation>Yearly</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1133"/>
        <source>End Repeat</source>
        <translation>End Repeat</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1144"/>
        <source>After</source>
        <translation>After</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1145"/>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1215"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1216"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="80"/>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>All occurrences of a repeating event must have the same all-day status.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="81"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="98"/>
        <source>Do you want to change all occurrences?</source>
        <translation>Do you want to change all occurrences?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="82"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="99"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="129"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="148"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="168"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="240"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="270"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="83"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="100"/>
        <source>Change All</source>
        <translation>Change All</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="97"/>
        <source>You are changing the repeating rule of this event.</source>
        <translation>You are changing the repeating rule of this event.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="127"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="146"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="166"/>
        <source>You are deleting an event.</source>
        <translation>You are deleting an event.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="128"/>
        <source>Are you sure you want to delete this event?</source>
        <translation>Are you sure you want to delete this event?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="130"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="147"/>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete all occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="149"/>
        <source>Delete All</source>
        <translation>Delete All</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="150"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="170"/>
        <source>Delete Only This Event</source>
        <translation>Delete Only This Event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="167"/>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="169"/>
        <source>Delete All Future Events</source>
        <translation>Delete All Future Events</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="236"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="266"/>
        <source>You are changing a repeating event.</source>
        <translation>You are changing a repeating event.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="238"/>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Do you want to change only this occurrence of the event, or all occurrences?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="241"/>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="242"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="272"/>
        <source>Only This Event</source>
        <translation>Only This Event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="268"/>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Do you want to change only this occurrence of the event, or this and all future occurrences?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="271"/>
        <source>All Future Events</source>
        <translation>All Future Events</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="383"/>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="384"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="905"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="905"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="905"/>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="42"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="43"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="267"/>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="648"/>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleview.cpp" line="316"/>
        <source>ALL DAY</source>
        <translation>ALL DAY</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="345"/>
        <source>Sunday</source>
        <translation>Sunday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="346"/>
        <source>Monday</source>
        <translation>Monday</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="obsolete">Tuesday</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="obsolete">Wednesday</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="obsolete">Thursday</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="obsolete">Friday</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="obsolete">Saturday</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="347"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="366"/>
        <source>Use System Setting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="364"/>
        <source>24-hour clock</source>
        <translation>24-hour clock</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="365"/>
        <source>12-hour clock</source>
        <translation>12-hour clock</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="389"/>
        <source>import ICS file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="403"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="404"/>
        <source>15 mins</source>
        <translation>15 mins</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="405"/>
        <source>30 mins</source>
        <translation>30 mins</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="406"/>
        <source>1 hour</source>
        <translation>1 hour</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="407"/>
        <source>24 hours</source>
        <translation>24 hours</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="418"/>
        <source>Sync Now</source>
        <translation>Sync Now</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="576"/>
        <source>Last sync</source>
        <translation>Last sync</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="770"/>
        <source>Please go to the &lt;a href=&apos;/&apos;&gt;Control Center&lt;/a&gt; to change system settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="71"/>
        <source>(%1 mins)</source>
        <translation>(%1 mins)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="73"/>
        <source>(%1 hour)</source>
        <translation>(%1 hour)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="75"/>
        <source>(%1 hours)</source>
        <translation>(%1 hours)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="30"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="42"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="50"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="58"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="92"/>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="93"/>
        <source>Search events and festivals</source>
        <translation>Search events and festivals</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation type="vanished">Sun</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation type="vanished">Mon</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation type="vanished">Tue</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation type="vanished">Wed</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation type="vanished">Thu</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation type="vanished">Fri</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation type="vanished">Sat</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="89"/>
        <source>Week</source>
        <translation>Week</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="276"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="268"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="271"/>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="288"/>
        <source>No event</source>
        <translation>No event</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="615"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="62"/>
        <source>Calendar</source>
        <translation>Calendar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="65"/>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="89"/>
        <source>Calendar</source>
        <translation>Calendar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="358"/>
        <source>Manage</source>
        <translation>Manage</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="365"/>
        <source>Privacy Policy</source>
        <translation>Privacy Policy</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="945"/>
        <source>Syncing...</source>
        <translation>Syncing...</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="955"/>
        <source>Sync successful</source>
        <translation>Sync successful</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="963"/>
        <source>Sync failed, please try later</source>
        <translation>Sync failed, please try later</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleRemindWidget.cpp" line="174"/>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation type="vanished">Work</translation>
    </message>
    <message>
        <source>Life</source>
        <translation type="vanished">Life</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="vanished">Other</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Close</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation type="vanished">One day before start</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Remind me tomorrow</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Remind me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="vanished">15 mins later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="vanished">1 hour later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="vanished">4 hours later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Tomorrow</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Schedule Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 to %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Today</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="47"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="48"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="49"/>
        <source>New event</source>
        <translation>New event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="737"/>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="143"/>
        <source>export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="214"/>
        <source>import ICS file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="401"/>
        <source>You are deleting an event type.</source>
        <translation>You are deleting an event type.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="402"/>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation>All events under this type will be deleted and cannot be recovered.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="403"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="404"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="96"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="127"/>
        <source>Manage calendar</source>
        <translation>Manage calendar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="112"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="131"/>
        <source>Event types</source>
        <translation>Event types</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="38"/>
        <source>Account settings</source>
        <translation>Account settings</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="42"/>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="53"/>
        <source>Select items to be synced</source>
        <translation>Select items to be synced</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="56"/>
        <source>Events</source>
        <translation>Events</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="63"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="146"/>
        <source>General settings</source>
        <translation>General settings</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="74"/>
        <source>Sync interval</source>
        <translation>Sync interval</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="104"/>
        <source>Calendar account</source>
        <translation>Calendar account</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="150"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="152"/>
        <source>First day of week</source>
        <translation>First day of week</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="153"/>
        <source>Time</source>
        <translation>Time</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="611"/>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="339"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="95"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="273"/>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="21"/>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="47"/>
        <source>New event type</source>
        <translation>New event type</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="31"/>
        <source>Edit event type</source>
        <translation>Edit event type</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="43"/>
        <source>Import ICS file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="140"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="141"/>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="145"/>
        <source>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="156"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="157"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="205"/>
        <source>The name can not only contain whitespaces</source>
        <translation>The name can not only contain whitespaces</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="241"/>
        <source>Enter a name please</source>
        <translation>Enter a name please</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="16"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="17"/>
        <source>Delete event</source>
        <translation>Delete event</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="20"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="21"/>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="22"/>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="25"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="26"/>
        <source>Select all</source>
        <translation>Select all</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="126"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="126"/>
        <source>M</source>
        <translation>M</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/timejumpdialog.cpp" line="29"/>
        <source>Go</source>
        <comment>button</comment>
        <translation>Go</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="48"/>
        <source>Sign In</source>
        <comment>button</comment>
        <translation>Sign In</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="49"/>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation>Sign Out</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="928"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="188"/>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="337"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="93"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="230"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="56"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="271"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="261"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="609"/>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Today</translation>
    </message>
</context>
</TS>
